@@ -7,22 +7,23 @@
  */
 
 #include "calendarindexer.h"
-#include "akonadi_indexer_agent_debug.h"
+#include "akonadi_indexer_agent_calendar_debug.h"
 #include "xapiandocument.h"
 
 #include <KCalendarCore/Attendee>
+#include <KCalendarCore/FreeBusy>
 
 CalendarIndexer::CalendarIndexer(const QString &path)
     : AbstractIndexer()
 {
     try {
-        m_db = new Akonadi::Search::XapianDatabase(path, true);
+        m_db = std::make_unique<Akonadi::Search::XapianDatabase>(path, true);
     } catch (const Xapian::DatabaseCorruptError &err) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+        qCWarning(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << "Database Corrupted - What did you do?";
+        qCWarning(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << err.get_error_string();
         m_db = nullptr;
     } catch (const Xapian::Error &e) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
+        qCWarning(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
         m_db = nullptr;
     }
 }
@@ -30,13 +31,16 @@ CalendarIndexer::CalendarIndexer(const QString &path)
 CalendarIndexer::~CalendarIndexer()
 {
     commit();
-    delete m_db;
 }
 
 QStringList CalendarIndexer::mimeTypes() const
 {
-    return QStringList() << QStringLiteral("application/x-vnd.akonadi.calendar.event") << QStringLiteral("application/x-vnd.akonadi.calendar.todo")
-                         << QStringLiteral("application/x-vnd.akonadi.calendar.journal") << QStringLiteral("application/x-vnd.akonadi.calendar.freebusy");
+    return {
+        KCalendarCore::Event::eventMimeType(),
+        KCalendarCore::Todo::todoMimeType(),
+        KCalendarCore::Journal::journalMimeType(),
+        KCalendarCore::FreeBusy::freeBusyMimeType(),
+    };
 }
 
 void CalendarIndexer::index(const Akonadi::Item &item)
@@ -61,9 +65,9 @@ void CalendarIndexer::commit()
     try {
         m_db->commit();
     } catch (const Xapian::Error &err) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+        qCWarning(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << err.get_error_string();
     }
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Xapian Committed";
+    qCDebug(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << "Xapian Committed";
 }
 
 void CalendarIndexer::remove(const Akonadi::Item &item)
@@ -121,16 +125,16 @@ void CalendarIndexer::move(Akonadi::Item::Id itemId, Akonadi::Collection::Id fro
 
 void CalendarIndexer::indexEventItem(const Akonadi::Item &item, const KCalendarCore::Event::Ptr &event)
 {
+    qCDebug(AKONADI_INDEXER_AGENT_CALENDAR_LOG) << "Indexing calendar event:" << normalizeString(event->summary()) << event->organizer().email();
+
     Akonadi::Search::XapianDocument doc;
 
     doc.indexText(event->organizer().email(), QStringLiteral("O"));
     doc.indexText(normalizeString(event->summary()), QStringLiteral("S"));
     doc.indexText(normalizeString(event->location()), QStringLiteral("L"));
     const KCalendarCore::Attendee::List attendees = event->attendees();
-    KCalendarCore::Attendee::List::ConstIterator it;
-    KCalendarCore::Attendee::List::ConstIterator end(attendees.constEnd());
-    for (it = attendees.constBegin(); it != end; ++it) {
-        doc.addBoolTerm((*it).email() + QString::number((*it).status()), QStringLiteral("PS"));
+    for (const KCalendarCore::Attendee &attendee : attendees) {
+        doc.addBoolTerm(attendee.email() + QString::number(attendee.status()), QStringLiteral("PS"));
     }
 
     // Parent collection
