@@ -5,12 +5,8 @@
 */
 
 #pragma once
-#include <QSyntaxHighlighter>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QRegExp>
-#else
 #include <QRegularExpression>
-#endif
+#include <QSyntaxHighlighter>
 namespace Akonadi
 {
 namespace Search
@@ -19,20 +15,12 @@ class Rule
 {
 public:
     Rule() = default;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Rule(const QRegExp &r, const QTextCharFormat &f)
-#else
     Rule(const QRegularExpression &r, const QTextCharFormat &f)
-#endif
         : pattern(r)
         , format(f)
     {
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QRegExp pattern;
-#else
     QRegularExpression pattern;
-#endif
     QTextCharFormat format;
 };
 
@@ -47,7 +35,7 @@ public:
 
 protected:
     void init();
-    QVector<Rule> m_rules;
+    QList<Rule> m_rules;
 };
 }
 }
