@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -31,17 +31,17 @@ public:
 
     void setOverrideDbPrefixPath(const QString &path);
 
-    qlonglong indexedItems(const qlonglong id);
+    [[nodiscard]] qlonglong indexedItems(const qlonglong id);
 
     void findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId, const QString &dbPath);
     void findIndexed(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId);
 
-    QString emailIndexingPath() const;
-    QString collectionIndexingPath() const;
-    QString calendarIndexingPath() const;
-    QString akonotesIndexingPath() const;
-    QString emailContactsIndexingPath() const;
-    QString contactIndexingPath() const;
+    [[nodiscard]] QString emailIndexingPath() const;
+    [[nodiscard]] QString collectionIndexingPath() const;
+    [[nodiscard]] QString calendarIndexingPath() const;
+    [[nodiscard]] QString akonotesIndexingPath() const;
+    [[nodiscard]] QString emailContactsIndexingPath() const;
+    [[nodiscard]] QString contactIndexingPath() const;
 
 private:
     std::unique_ptr<IndexedItemsPrivate> const d;
